/* Example of using the DOM to parse a simple XML file 
 * 
 * Takes a single command-line argument specifying an XML file like:
 * 
 * <notes>
 * 	<note id="12345">
 *     <to>Tove</to> 
 *     <from>Jani</from> 
 *     <heading>Reminder</heading> 
 *     <body>Don't forget me this weekend!</body>
 * </note>
 * <note id="12346">
 *     <to>Keith</to> 
 *     <from>Vertanen</from> 
 *     <heading>Launch the missiles!</heading> 
 *     <body>It's the end of the world as we know it (and I feel fine).</body>
 * </note>
 * </notes>
 * 
 **/

import javax.xml.parsers.*;
import org.w3c.dom.*;
import org.xml.sax.SAXException;
import java.io.*;

public class ReadDOM 
{
	public static void main(String [] args)
	{
		try
		{
			DocumentBuilderFactory   dbFactory   = DocumentBuilderFactory.newInstance();
			DocumentBuilder          dBuilder    = dbFactory.newDocumentBuilder();
			Document                 doc         = dBuilder.parse(new File(args[0]));
			
			doc.getDocumentElement().normalize();

			System.out.println("Root element : " + doc.getDocumentElement().getNodeName());
			 
			NodeList list = doc.getElementsByTagName("note");
			
			for (int i = 0; i < list.getLength(); i++) 
			{				 
				Node node = list.item(i);
		 
				System.out.println("\nCurrent Element :" + node.getNodeName());
				
				if (node.getNodeType() == Node.ELEMENT_NODE) 
				{
					Element element = (Element) node;
		 
					System.out.println("Note ID : " + element.getAttribute("id"));
					System.out.println("To      : " + element.getElementsByTagName("to").item(0).getTextContent());
					System.out.println("From    : " + element.getElementsByTagName("from").item(0).getTextContent());
					System.out.println("Heading : " + element.getElementsByTagName("heading").item(0).getTextContent());
					System.out.println("Body    : " + element.getElementsByTagName("body").item(0).getTextContent());
				}
			}
		}
		catch (IOException e)
		{
			System.out.println("Unable to read file: " + args[0]);
			return;
		} 
		catch (ParserConfigurationException e) 
		{
			System.out.println("Failed to parse: " + args[0]);
			return;
		} 
		catch (SAXException e) 
		{
			System.out.println("Failed to parse: " + args[0]);
			return;
		}
	}
}
